@@ -22,7 +22,7 @@ from eden.util import serialize_dict
 from itertools import tee
 import logging
 logger = logging.getLogger(__name__)
-
+from multiprocessing import Pool 
 
 def auto_label(graphs, n_clusters=16, **opts):
     """Label nodes with cluster id.
@@ -65,10 +65,16 @@ def vectorize(graphs, **opts):
     return Vectorizer(**opts).transform(graphs)
 
 
+def noname(x):
+    x,y = x
+    return y.vertex_transform([x])[0]
+
 def vertex_vectorize(graphs, **opts):
     """Transform a list of networkx graphs into a list of sparse matrices."""
-    return Vectorizer(**opts).vertex_transform(graphs)
-
+    poo = Pool(processes=8)
+    res = poo.map(noname, [(g,Vectorizer()) for g in graphs])
+    poo.close()
+    return res
 
 def annotate(graphs,
              estimator=None,
@@ -106,6 +112,7 @@ class Vectorizer(AbstractVectorizer):
                  inner_normalization=True,
                  positional=False,
                  discrete=True,
+                 use_only_context=False,
                  key_label='label',
                  key_weight='weight',
                  key_nesting='nesting',
@@ -163,6 +170,10 @@ class Vectorizer(AbstractVectorizer):
             Flag to activate more efficient computation of vectorization
             considering only discrete labels and ignoring vector attributes.
 
+        use_only_context: bool (default False)
+            Flag to deactivate the central part of the information
+            and retain only the context.
+
         key_label : string (default 'label')
             The key used to indicate the label information in nodes.
 
@@ -205,6 +216,7 @@ class Vectorizer(AbstractVectorizer):
         self.inner_normalization = inner_normalization
         self.positional = positional
         self.discrete = discrete
+        self.use_only_context = use_only_context
         self.bitmask = pow(2, nbits) - 1
         self.feature_size = self.bitmask + 2
         self.key_label = key_label
@@ -566,7 +578,8 @@ class Vectorizer(AbstractVectorizer):
             half_feature = fast_hash_3(vertex_u_hash,
                                        radius, distance, self.bitmask)
             if graph.graph.get('weighted', False) is False:
-                feature_list[radius_dist_key][feature] += cw
+                if self.use_only_context is False:
+                    feature_list[radius_dist_key][feature] += cw
                 feature_list[radius_dist_key][half_feature] += cw
             else:
                 weight_v = graph.nodes[vertex_v]['neigh_graph_weight']
@@ -575,7 +588,8 @@ class Vectorizer(AbstractVectorizer):
                 val = cw * weight_vu_radius
                 # Note: add a feature only if the value is not 0
                 if val != 0:
-                    feature_list[radius_dist_key][feature] += val
+                    if self.use_only_context is False:
+                        feature_list[radius_dist_key][feature] += val
                     half_val = cw * weight_u[radius]
                     feature_list[radius_dist_key][half_feature] += half_val
 
@@ -933,7 +947,7 @@ def _edge_to_vertex_transform(original_graph):
         for n in graph:
             graph.nodes[n]['node'] = True
         # add a new vertex for each edge
-        w = 1+max(graph.nodes())
+        w = 1 + max(graph.nodes())
         for u, v in original_graph.edges():
             if u != v:
                 graph.add_node(w)
@@ -959,8 +973,11 @@ def _revert_edge_to_vertex_transform(original_graph):
                 # extract the endpoints
                 endpoints = [u for u in original_graph.neighbors(n)]
                 if len(endpoints) != 2:
-                    raise Exception('ERROR: more than 2 endpoints in \
-                        a single edge: %s' % endpoints)
+                    for u in original_graph.nodes():
+                        print(original_graph.nodes[u])
+                    for u, v in original_graph.edges():
+                        print(original_graph.edges[u, v])
+                    raise Exception('ERROR: expecting 2 endpoints in a single edge, instead got: %s' % endpoints)
                 u = endpoints[0]
                 v = endpoints[1]
                 # add the corresponding edge
